@@ -1,17 +1,19 @@
 #!/usr/bin/env python
 # -*- encoding: utf-8 -*-
-'''
+"""
 @File    :   cmdHelper.py
 @Time    :   2019/02/27
 @Author  :   Yaronzz 
 @Version :   2.2
 @Contact :   yaronhuang@foxmail.com
 @Desc    :   
-'''
+"""
 import os
 import sys
 from enum import Enum
+
 from colorama import init
+
 from aigpy.pathHelper import mkdirs
 
 init(autoreset=True)
@@ -25,9 +27,18 @@ def isInputYes(string: str) -> bool:
     return False
 
 
+def printW(desc: str, wrap: bool = True):
+    """Print desc width wrap or not"""
+    if not wrap:
+        sys.stdout.write(desc)
+    else:
+        print(desc)
+
+
 def inputInt(desc: str, default: int) -> int:
     try:
-        string = input(desc)
+        printW(desc, False)
+        string = input()
         return int(string)
     except ValueError:
         return default
@@ -35,7 +46,8 @@ def inputInt(desc: str, default: int) -> int:
 
 def inputFloat(desc: str, default: int) -> float:
     try:
-        string = input(desc)
+        printW(desc, False)
+        string = input()
         return float(string)
     except ValueError:
         return default
@@ -48,7 +60,8 @@ def inputPath(desc: str, ignore: str = "") -> str:
     return:
     - path: existed or mkdirs success
     """
-    path = input(desc)
+    printW(desc, False)
+    path = input()
     if path == ignore:
         return ignore
     if os.path.isdir(path) or mkdirs(path):
@@ -64,20 +77,13 @@ def inputLimit(desc: str, limit: list) -> str:
     - path: input string in limit list
     - none
     """
-    string = input(desc)
+    printW(desc, False)
+    string = input()
     if string in limit:
         return string
     return None
 
 
-def printW(desc: str, wrap: bool = True):
-    """Print desc width wrap or not"""
-    if not wrap:
-        sys.stdout.write(desc)
-    else:
-        print(desc)
-
-
 def isInArgv(string):
     array = sys.argv
     if array is None or len(array) <= 0:
