@@ -1,17 +1,18 @@
 #!/usr/bin/env python
 # -*- encoding: utf-8 -*-
-'''
+"""
 @File    :   pathHelper.py
 @Time    :   2018/12/17
 @Author  :   Yaronzz 
 @Version :   2.0
 @Contact :   yaronhuang@foxmail.com
-@Desc    :   
-'''
+@Desc    :  
+"""
 
 import os
 import shutil
 
+
 def getTmpPath(basePath: str) -> str:
     """Get tmp path name like 'Tmp1'"""
     basePath = basePath.replace("\\", "/").strip().rstrip("/")
@@ -19,7 +20,7 @@ def getTmpPath(basePath: str) -> str:
     path = basePath + '/Tmp' + str(count)
     while os.path.exists(path):
         count = count + 1
-        path  = basePath + '/Tmp' + str(count)
+        path = basePath + '/Tmp' + str(count)
     return path
 
 
@@ -53,11 +54,11 @@ def remove(path: str) -> bool:
 def copyFile(srcfile: str, dstfile: str) -> bool:
     if not os.path.isfile(srcfile):
         return False
-    
-    path, name = os.path.split(dstfile)  
+
+    path, name = os.path.split(dstfile)
     if not os.path.exists(path):
         mkdirs(path)
-    shutil.copyfile(srcfile, dstfile) 
+    shutil.copyfile(srcfile, dstfile)
     return True
 
 
@@ -75,6 +76,8 @@ def replaceLimitChar(path: str, newChar: str) -> str:
     path = path.replace('\\', newChar)
     path = path.replace('*', newChar)
     path = path.replace('\"', newChar)
+    path = path.replace('\n', '')
+    path = path.replace('\t', '')
     path = path.rstrip('.')
     path = path.strip(' ')
     return path
@@ -83,10 +86,10 @@ def replaceLimitChar(path: str, newChar: str) -> str:
 def getDirName(filepath: str) -> str:
     """e:/test/file.txt --> e:/test/"""
     filepath = filepath.replace('\\', '/')
-    index    = filepath.rfind('/')
+    index = filepath.rfind('/')
     if index < 0:
         return './'
-    return filepath[0:index+1]
+    return filepath[0:index + 1]
 
 
 def getFileName(filepath: str) -> str:
@@ -95,7 +98,7 @@ def getFileName(filepath: str) -> str:
     index = filepath.rfind('/')
     if index < 0:
         return filepath
-    return filepath[index+1:len(filepath)]
+    return filepath[index + 1:len(filepath)]
 
 
 def getFileNameWithoutExtension(filepath: str) -> str:
@@ -121,7 +124,7 @@ def getSize(path: str) -> int:
         size = 0
         if os.path.isdir(path) is False:
             return size
-        
+
         for root, dirs, files in os.walk(path):
             size += sum([os.path.getsize(os.path.join(root, name)) for name in files])
         return size
@@ -134,12 +137,11 @@ def getFiles(path: str) -> list:
         ret = []
         if os.path.isdir(path) is False:
             return ret
-        
+
         for root, dirs, files in os.walk(path):
-            root = root.replace('\\','/')
+            root = root.replace('\\', '/')
             for item in files:
                 ret.append(root + '/' + item)
         return ret
     except:
         return []
-
