@@ -1,13 +1,13 @@
 #!/usr/bin/env python
 # -*- encoding: utf-8 -*-
-'''
+"""
 @File    :   stringHelper.py
 @Time    :   2019/03/11
 @Author  :   Yaronzz 
 @Version :   2.0
 @Contact :   yaronhuang@foxmail.com
-@Desc    :   
-'''
+@Desc    :  
+"""
 
 
 def isNull(word):
@@ -32,7 +32,7 @@ def isChinese(word, checkPunctuation=False):
     return False
 
 
-def converPunctuationToEnglish(word):
+def convertPunctuationToEnglish(word):
     table = {ord(f): ord(t) for f, t in zip(
         u'，。！？【】（）％＃＠＆１２３４５６７８９０：',
         u',.!?[]()%#@&1234567890:')}
@@ -90,6 +90,3 @@ def getSub(string, start=None, end=None):
     if ret == "":
         ret = string
     return ret
-
-
-
